@@ -37,8 +37,3 @@ class NotFriendsError(Exception):
 class AlreadyFriendsError(Exception):
     ## When users are already friends
     pass
-
-class RateLimitError(Exception):
-    ## When hit rate limit
-    ## Right now this is an artificial limit of 1 minute
-    pass
